@@ -1,6 +1,7 @@
 from meilisearch.index import Index
 from meilisearch.config import Config
 from meilisearch._httprequests import HttpRequests
+from meilisearch.errors import MeiliSearchApiError
 
 class Client():
     """
@@ -80,6 +81,33 @@ class Client():
         """
         return Index.get_index(self.config, uid=uid)
 
+    def get_or_create_index(self, uid, options=None):
+        """Get an index, or create it if it doesn't exist.
+
+        Parameters
+        ----------
+        uid: str
+            UID of the index
+        options: dict, optional
+            Options passed during index creation (ex: primaryKey)
+
+        Returns
+        -------
+        index : Index
+            an instance of Index containing the information of the retrieved or newly created index
+        Raises
+        ------
+        HTTPError
+            In case of any other error found here https://docs.meilisearch.com/references/#errors-status-code
+        """
+        index = self.get_index(uid)
+        try:
+            index.create(self.config, uid, options)
+        except MeiliSearchApiError as err:
+            if err.error_code != 'index_already_exists':
+                raise err
+        return index
+
     def get_all_stats(self):
         """Get all stats of MeiliSearch
 
@@ -129,18 +157,6 @@ class Client():
         """
         return self.http.get(self.config.paths.keys)
 
-    def get_sys_info(self):
-        """Get system information of MeiliSearch
-
-        Get information about memory usage and processor usage.
-
-        Returns
-        ----------
-        sys_info: dict
-            Information about memory and processor usage.
-        """
-        return self.http.get(self.config.paths.sys_info)
-
     def get_version(self):
         """Get version MeiliSearch
 
