@@ -1,4 +1,3 @@
-import json
 import urllib
 from datetime import datetime
 from time import sleep
@@ -105,7 +104,7 @@ class Index():
         """
         if options is None:
             options = {}
-        payload = {'uid': uid, **options}
+        payload = {**options, 'uid': uid}
         return HttpRequests(config).post(config.paths.index, payload)
 
     @staticmethod
@@ -239,24 +238,18 @@ class Index():
         results: `dict`
             Dictionnary with hits, offset, limit, processingTime and initial query
         """
-        # Query parameters parsing
         if opt_params is None:
             opt_params = {}
-        for key in opt_params:
-            if key in ('facetsDistribution', 'facetFilters'):
-                opt_params[key] = json.dumps(opt_params[key])
-            elif isinstance(opt_params[key], list):
-                opt_params[key] = ','.join(opt_params[key])
-        params = {
+        body = {
             'q': query,
             **opt_params
         }
-        return self.http.get(
-            '{}/{}/{}?{}'.format(
+        return self.http.post(
+            '{}/{}/{}'.format(
                 self.config.paths.index,
                 self.uid,
-                self.config.paths.search,
-                urllib.parse.urlencode(params))
+                self.config.paths.search),
+            body=body
         )
 
     def get_document(self, document_id):
@@ -780,41 +773,6 @@ class Index():
             self.__settings_url_for(self.config.paths.synonyms),
         )
 
-    # ACCEPT-NEW-FIELDS SUB-ROUTES
-
-    def get_accept_new_fields(self):
-        """
-        Get accept-new-fields value of an index
-
-        Returns
-        ----------
-        settings: `bool`
-            Boolean containing the accept-new-fields value of the index
-        """
-        return self.http.get(
-            self.__settings_url_for(self.config.paths.accept_new_fields)
-        )
-
-    def update_accept_new_fields(self, body):
-        """
-        Update accept-new-fields value of an index
-
-        Parameters
-        ----------
-        body: `bool`
-            Boolean containing the accept-new-fields value
-
-        Returns
-        ----------
-        update: `dict`
-            Dictionnary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
-        """
-        return self.http.post(
-            self.__settings_url_for(self.config.paths.accept_new_fields),
-            body
-        )
-
     # ATTRIBUTES FOR FACETING SUB-ROUTES
 
     def get_attributes_for_faceting(self):
